.. _linalg:


Linear algebra
**************

.. currentmodule:: networkx

Spectrum
---------
.. automodule:: networkx.linalg.spectrum
.. autosummary::
   :toctree: generated/

   adj_matrix
   laplacian
   normalized_laplacian
   laplacian_spectrum
   adjacency_spectrum


Attribute Matrices
------------------

.. automodule:: networkx.linalg.attrmatrix
.. autosummary::
   :toctree: generated/

   attr_matrix
   attr_sparse_matrix
